Class: Aws::CloudWatchEvidently::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::CloudWatchEvidently::Client
- Includes:
- Aws::ClientStubs
- Defined in:
- lib/aws-sdk-cloudwatchevidently/client.rb
Overview
An API client for CloudWatchEvidently. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::CloudWatchEvidently::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#batch_evaluate_feature(params = {}) ⇒ Types::BatchEvaluateFeatureResponse
This operation assigns feature variation to user sessions.
-
#create_experiment(params = {}) ⇒ Types::CreateExperimentResponse
Creates an Evidently experiment.
-
#create_feature(params = {}) ⇒ Types::CreateFeatureResponse
Creates an Evidently feature that you want to launch or test.
-
#create_launch(params = {}) ⇒ Types::CreateLaunchResponse
Creates a launch of a given feature.
-
#create_project(params = {}) ⇒ Types::CreateProjectResponse
Creates a project, which is the logical object in Evidently that can contain features, launches, and experiments.
-
#create_segment(params = {}) ⇒ Types::CreateSegmentResponse
Use this operation to define a segment of your audience.
-
#delete_experiment(params = {}) ⇒ Struct
Deletes an Evidently experiment.
-
#delete_feature(params = {}) ⇒ Struct
Deletes an Evidently feature.
-
#delete_launch(params = {}) ⇒ Struct
Deletes an Evidently launch.
-
#delete_project(params = {}) ⇒ Struct
Deletes an Evidently project.
-
#delete_segment(params = {}) ⇒ Struct
Deletes a segment.
-
#evaluate_feature(params = {}) ⇒ Types::EvaluateFeatureResponse
This operation assigns a feature variation to one given user session.
-
#get_experiment(params = {}) ⇒ Types::GetExperimentResponse
Returns the details about one experiment.
-
#get_experiment_results(params = {}) ⇒ Types::GetExperimentResultsResponse
Retrieves the results of a running or completed experiment.
-
#get_feature(params = {}) ⇒ Types::GetFeatureResponse
Returns the details about one feature.
-
#get_launch(params = {}) ⇒ Types::GetLaunchResponse
Returns the details about one launch.
-
#get_project(params = {}) ⇒ Types::GetProjectResponse
Returns the details about one launch.
-
#get_segment(params = {}) ⇒ Types::GetSegmentResponse
Returns information about the specified segment.
-
#list_experiments(params = {}) ⇒ Types::ListExperimentsResponse
Returns configuration details about all the experiments in the specified project.
-
#list_features(params = {}) ⇒ Types::ListFeaturesResponse
Returns configuration details about all the features in the specified project.
-
#list_launches(params = {}) ⇒ Types::ListLaunchesResponse
Returns configuration details about all the launches in the specified project.
-
#list_projects(params = {}) ⇒ Types::ListProjectsResponse
Returns configuration details about all the projects in the current Region in your account.
-
#list_segment_references(params = {}) ⇒ Types::ListSegmentReferencesResponse
Use this operation to find which experiments or launches are using a specified segment.
-
#list_segments(params = {}) ⇒ Types::ListSegmentsResponse
Returns a list of audience segments that you have created in your account in this Region.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Displays the tags associated with an Evidently resource.
-
#put_project_events(params = {}) ⇒ Types::PutProjectEventsResponse
Sends performance events to Evidently.
-
#start_experiment(params = {}) ⇒ Types::StartExperimentResponse
Starts an existing experiment.
-
#start_launch(params = {}) ⇒ Types::StartLaunchResponse
Starts an existing launch.
-
#stop_experiment(params = {}) ⇒ Types::StopExperimentResponse
Stops an experiment that is currently running.
-
#stop_launch(params = {}) ⇒ Types::StopLaunchResponse
Stops a launch that is currently running.
-
#tag_resource(params = {}) ⇒ Struct
Assigns one or more tags (key-value pairs) to the specified CloudWatch Evidently resource.
-
#test_segment_pattern(params = {}) ⇒ Types::TestSegmentPatternResponse
Use this operation to test a rules pattern that you plan to use to create an audience segment.
-
#untag_resource(params = {}) ⇒ Struct
Removes one or more tags from the specified resource.
-
#update_experiment(params = {}) ⇒ Types::UpdateExperimentResponse
Updates an Evidently experiment.
-
#update_feature(params = {}) ⇒ Types::UpdateFeatureResponse
Updates an existing feature.
-
#update_launch(params = {}) ⇒ Types::UpdateLaunchResponse
Updates a launch of a given feature.
-
#update_project(params = {}) ⇒ Types::UpdateProjectResponse
Updates the description of an existing project.
-
#update_project_data_delivery(params = {}) ⇒ Types::UpdateProjectDataDeliveryResponse
Updates the data storage options for this project.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
473 474 475 |
# File 'lib/aws-sdk-cloudwatchevidently/client.rb', line 473 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3248 3249 3250 |
# File 'lib/aws-sdk-cloudwatchevidently/client.rb', line 3248 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3251 3252 3253 |
# File 'lib/aws-sdk-cloudwatchevidently/client.rb', line 3251 def errors_module Errors end |
Instance Method Details
#batch_evaluate_feature(params = {}) ⇒ Types::BatchEvaluateFeatureResponse
This operation assigns feature variation to user sessions. For each user session, you pass in an ‘entityID` that represents the user. Evidently then checks the evaluation rules and assigns the variation.
The first rules that are evaluated are the override rules. If the user’s ‘entityID` matches an override rule, the user is served the variation specified by that rule.
Next, if there is a launch of the feature, the user might be assigned to a variation in the launch. The chance of this depends on the percentage of users that are allocated to that launch. If the user is enrolled in the launch, the variation they are served depends on the allocation of the various feature variations used for the launch.
If the user is not assigned to a launch, and there is an ongoing experiment for this feature, the user might be assigned to a variation in the experiment. The chance of this depends on the percentage of users that are allocated to that experiment. If the user is enrolled in the experiment, the variation they are served depends on the allocation of the various feature variations used for the experiment.
If the user is not assigned to a launch or experiment, they are served the default variation.
546 547 548 549 |
# File 'lib/aws-sdk-cloudwatchevidently/client.rb', line 546 def batch_evaluate_feature(params = {}, = {}) req = build_request(:batch_evaluate_feature, params) req.send_request() end |
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3221 3222 3223 3224 3225 3226 3227 3228 3229 3230 3231 3232 3233 3234 3235 3236 3237 |
# File 'lib/aws-sdk-cloudwatchevidently/client.rb', line 3221 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::CloudWatchEvidently') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-cloudwatchevidently' context[:gem_version] = '1.51.0' Seahorse::Client::Request.new(handlers, context) end |
#create_experiment(params = {}) ⇒ Types::CreateExperimentResponse
Creates an Evidently experiment. Before you create an experiment, you must create the feature to use for the experiment.
An experiment helps you make feature design decisions based on evidence and data. An experiment can test as many as five variations at once. Evidently collects experiment data and analyzes it by statistical methods, and provides clear recommendations about which variations perform better.
You can optionally specify a ‘segment` to have the experiment consider only certain audience types in the experiment, such as using only user sessions from a certain location or who use a certain internet browser.
Don’t use this operation to update an existing experiment. Instead, use [UpdateExperiment].
[1]: docs.aws.amazon.com/cloudwatchevidently/latest/APIReference/API_UpdateExperiment.html
719 720 721 722 |
# File 'lib/aws-sdk-cloudwatchevidently/client.rb', line 719 def create_experiment(params = {}, = {}) req = build_request(:create_experiment, params) req.send_request() end |
#create_feature(params = {}) ⇒ Types::CreateFeatureResponse
Creates an Evidently feature that you want to launch or test. You can define up to five variations of a feature, and use these variations in your launches and experiments. A feature must be created in a project. For information about creating a project, see [CreateProject].
Don’t use this operation to update an existing feature. Instead, use [UpdateFeature].
[1]: docs.aws.amazon.com/cloudwatchevidently/latest/APIReference/API_CreateProject.html [2]: docs.aws.amazon.com/cloudwatchevidently/latest/APIReference/API_UpdateFeature.html
855 856 857 858 |
# File 'lib/aws-sdk-cloudwatchevidently/client.rb', line 855 def create_feature(params = {}, = {}) req = build_request(:create_feature, params) req.send_request() end |
#create_launch(params = {}) ⇒ Types::CreateLaunchResponse
Creates a launch of a given feature. Before you create a launch, you must create the feature to use for the launch.
You can use a launch to safely validate new features by serving them to a specified percentage of your users while you roll out the feature. You can monitor the performance of the new feature to help you decide when to ramp up traffic to more users. This helps you reduce risk and identify unintended consequences before you fully launch the feature.
Don’t use this operation to update an existing launch. Instead, use [UpdateLaunch].
[1]: docs.aws.amazon.com/cloudwatchevidently/latest/APIReference/API_UpdateLaunch.html
1018 1019 1020 1021 |
# File 'lib/aws-sdk-cloudwatchevidently/client.rb', line 1018 def create_launch(params = {}, = {}) req = build_request(:create_launch, params) req.send_request() end |
#create_project(params = {}) ⇒ Types::CreateProjectResponse
Creates a project, which is the logical object in Evidently that can contain features, launches, and experiments. Use projects to group similar features together.
To update an existing project, use [UpdateProject].
[1]: docs.aws.amazon.com/cloudwatchevidently/latest/APIReference/API_UpdateProject.html
1137 1138 1139 1140 |
# File 'lib/aws-sdk-cloudwatchevidently/client.rb', line 1137 def create_project(params = {}, = {}) req = build_request(:create_project, params) req.send_request() end |
#create_segment(params = {}) ⇒ Types::CreateSegmentResponse
Use this operation to define a segment of your audience. A segment is a portion of your audience that share one or more characteristics. Examples could be Chrome browser users, users in Europe, or Firefox browser users in Europe who also fit other criteria that your application collects, such as age.
Using a segment in an experiment limits that experiment to evaluate only the users who match the segment criteria. Using one or more segments in a launch allows you to define different traffic splits for the different audience segments.
For more information about segment pattern syntax, see [ Segment rule pattern syntax].
The pattern that you define for a segment is matched against the value of ‘evaluationContext`, which is passed into Evidently in the
- EvaluateFeature][2
-
operation, when Evidently assigns a feature
variation to a user.
[1]: docs.aws.amazon.com/AmazonCloudWatch/latest/monitoring/CloudWatch-Evidently-segments.html#CloudWatch-Evidently-segments-syntax.html [2]: docs.aws.amazon.com/cloudwatchevidently/latest/APIReference/API_EvaluateFeature.html
1234 1235 1236 1237 |
# File 'lib/aws-sdk-cloudwatchevidently/client.rb', line 1234 def create_segment(params = {}, = {}) req = build_request(:create_segment, params) req.send_request() end |
#delete_experiment(params = {}) ⇒ Struct
Deletes an Evidently experiment. The feature used for the experiment is not deleted.
To stop an experiment without deleting it, use [StopExperiment].
[1]: docs.aws.amazon.com/cloudwatchevidently/latest/APIReference/API_StopExperiment.html
1267 1268 1269 1270 |
# File 'lib/aws-sdk-cloudwatchevidently/client.rb', line 1267 def delete_experiment(params = {}, = {}) req = build_request(:delete_experiment, params) req.send_request() end |
#delete_feature(params = {}) ⇒ Struct
Deletes an Evidently feature.
1293 1294 1295 1296 |
# File 'lib/aws-sdk-cloudwatchevidently/client.rb', line 1293 def delete_feature(params = {}, = {}) req = build_request(:delete_feature, params) req.send_request() end |
#delete_launch(params = {}) ⇒ Struct
Deletes an Evidently launch. The feature used for the launch is not deleted.
To stop a launch without deleting it, use [StopLaunch].
[1]: docs.aws.amazon.com/cloudwatchevidently/latest/APIReference/API_StopLaunch.html
1326 1327 1328 1329 |
# File 'lib/aws-sdk-cloudwatchevidently/client.rb', line 1326 def delete_launch(params = {}, = {}) req = build_request(:delete_launch, params) req.send_request() end |
#delete_project(params = {}) ⇒ Struct
Deletes an Evidently project. Before you can delete a project, you must delete all the features that the project contains. To delete a feature, use [DeleteFeature].
[1]: docs.aws.amazon.com/cloudwatchevidently/latest/APIReference/API_DeleteFeature.html
1354 1355 1356 1357 |
# File 'lib/aws-sdk-cloudwatchevidently/client.rb', line 1354 def delete_project(params = {}, = {}) req = build_request(:delete_project, params) req.send_request() end |
#delete_segment(params = {}) ⇒ Struct
Deletes a segment. You can’t delete a segment that is being used in a launch or experiment, even if that launch or experiment is not currently running.
1378 1379 1380 1381 |
# File 'lib/aws-sdk-cloudwatchevidently/client.rb', line 1378 def delete_segment(params = {}, = {}) req = build_request(:delete_segment, params) req.send_request() end |
#evaluate_feature(params = {}) ⇒ Types::EvaluateFeatureResponse
This operation assigns a feature variation to one given user session. You pass in an ‘entityID` that represents the user. Evidently then checks the evaluation rules and assigns the variation.
The first rules that are evaluated are the override rules. If the user’s ‘entityID` matches an override rule, the user is served the variation specified by that rule.
If there is a current launch with this feature that uses segment overrides, and if the user session’s ‘evaluationContext` matches a segment rule defined in a segment override, the configuration in the segment overrides is used. For more information about segments, see
- CreateSegment][1
-
and [Use segments to focus your audience].
If there is a launch with no segment overrides, the user might be assigned to a variation in the launch. The chance of this depends on the percentage of users that are allocated to that launch. If the user is enrolled in the launch, the variation they are served depends on the allocation of the various feature variations used for the launch.
If the user is not assigned to a launch, and there is an ongoing experiment for this feature, the user might be assigned to a variation in the experiment. The chance of this depends on the percentage of users that are allocated to that experiment.
If the experiment uses a segment, then only user sessions with ‘evaluationContext` values that match the segment rule are used in the experiment.
If the user is enrolled in the experiment, the variation they are served depends on the allocation of the various feature variations used for the experiment.
If the user is not assigned to a launch or experiment, they are served the default variation.
[1]: docs.aws.amazon.com/cloudwatchevidently/latest/APIReference/API_CreateSegment.html [2]: docs.aws.amazon.com/AmazonCloudWatch/latest/monitoring/CloudWatch-Evidently-segments.html
1483 1484 1485 1486 |
# File 'lib/aws-sdk-cloudwatchevidently/client.rb', line 1483 def evaluate_feature(params = {}, = {}) req = build_request(:evaluate_feature, params) req.send_request() end |
#get_experiment(params = {}) ⇒ Types::GetExperimentResponse
Returns the details about one experiment. You must already know the experiment name. To retrieve a list of experiments in your account, use [ListExperiments].
[1]: docs.aws.amazon.com/cloudwatchevidently/latest/APIReference/API_ListExperiments.html
1552 1553 1554 1555 |
# File 'lib/aws-sdk-cloudwatchevidently/client.rb', line 1552 def get_experiment(params = {}, = {}) req = build_request(:get_experiment, params) req.send_request() end |
#get_experiment_results(params = {}) ⇒ Types::GetExperimentResultsResponse
Retrieves the results of a running or completed experiment. No results are available until there have been 100 events for each variation and at least 10 minutes have passed since the start of the experiment. To increase the statistical power, Evidently performs an additional offline p-value analysis at the end of the experiment. Offline p-value analysis can detect statistical significance in some cases where the anytime p-values used during the experiment do not find statistical significance.
Experiment results are available up to 63 days after the start of the experiment. They are not available after that because of CloudWatch data retention policies.
1671 1672 1673 1674 |
# File 'lib/aws-sdk-cloudwatchevidently/client.rb', line 1671 def get_experiment_results(params = {}, = {}) req = build_request(:get_experiment_results, params) req.send_request() end |
#get_feature(params = {}) ⇒ Types::GetFeatureResponse
Returns the details about one feature. You must already know the feature name. To retrieve a list of features in your account, use [ListFeatures].
[1]: docs.aws.amazon.com/cloudwatchevidently/latest/APIReference/API_ListFeatures.html
1731 1732 1733 1734 |
# File 'lib/aws-sdk-cloudwatchevidently/client.rb', line 1731 def get_feature(params = {}, = {}) req = build_request(:get_feature, params) req.send_request() end |
#get_launch(params = {}) ⇒ Types::GetLaunchResponse
Returns the details about one launch. You must already know the launch name. To retrieve a list of launches in your account, use [ListLaunches].
[1]: docs.aws.amazon.com/cloudwatchevidently/latest/APIReference/API_ListLaunches.html
1802 1803 1804 1805 |
# File 'lib/aws-sdk-cloudwatchevidently/client.rb', line 1802 def get_launch(params = {}, = {}) req = build_request(:get_launch, params) req.send_request() end |
#get_project(params = {}) ⇒ Types::GetProjectResponse
Returns the details about one launch. You must already know the project name. To retrieve a list of projects in your account, use [ListProjects].
[1]: docs.aws.amazon.com/cloudwatchevidently/latest/APIReference/API_ListProjects.html
1854 1855 1856 1857 |
# File 'lib/aws-sdk-cloudwatchevidently/client.rb', line 1854 def get_project(params = {}, = {}) req = build_request(:get_project, params) req.send_request() end |
#get_segment(params = {}) ⇒ Types::GetSegmentResponse
Returns information about the specified segment. Specify the segment you want to view by specifying its ARN.
1892 1893 1894 1895 |
# File 'lib/aws-sdk-cloudwatchevidently/client.rb', line 1892 def get_segment(params = {}, = {}) req = build_request(:get_segment, params) req.send_request() end |
#list_experiments(params = {}) ⇒ Types::ListExperimentsResponse
Returns configuration details about all the experiments in the specified project.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1971 1972 1973 1974 |
# File 'lib/aws-sdk-cloudwatchevidently/client.rb', line 1971 def list_experiments(params = {}, = {}) req = build_request(:list_experiments, params) req.send_request() end |
#list_features(params = {}) ⇒ Types::ListFeaturesResponse
Returns configuration details about all the features in the specified project.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2026 2027 2028 2029 |
# File 'lib/aws-sdk-cloudwatchevidently/client.rb', line 2026 def list_features(params = {}, = {}) req = build_request(:list_features, params) req.send_request() end |
#list_launches(params = {}) ⇒ Types::ListLaunchesResponse
Returns configuration details about all the launches in the specified project.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2107 2108 2109 2110 |
# File 'lib/aws-sdk-cloudwatchevidently/client.rb', line 2107 def list_launches(params = {}, = {}) req = build_request(:list_launches, params) req.send_request() end |
#list_projects(params = {}) ⇒ Types::ListProjectsResponse
Returns configuration details about all the projects in the current Region in your account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2158 2159 2160 2161 |
# File 'lib/aws-sdk-cloudwatchevidently/client.rb', line 2158 def list_projects(params = {}, = {}) req = build_request(:list_projects, params) req.send_request() end |
#list_segment_references(params = {}) ⇒ Types::ListSegmentReferencesResponse
Use this operation to find which experiments or launches are using a specified segment.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2213 2214 2215 2216 |
# File 'lib/aws-sdk-cloudwatchevidently/client.rb', line 2213 def list_segment_references(params = {}, = {}) req = build_request(:list_segment_references, params) req.send_request() end |
#list_segments(params = {}) ⇒ Types::ListSegmentsResponse
Returns a list of audience segments that you have created in your account in this Region.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2262 2263 2264 2265 |
# File 'lib/aws-sdk-cloudwatchevidently/client.rb', line 2262 def list_segments(params = {}, = {}) req = build_request(:list_segments, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Displays the tags associated with an Evidently resource.
2291 2292 2293 2294 |
# File 'lib/aws-sdk-cloudwatchevidently/client.rb', line 2291 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#put_project_events(params = {}) ⇒ Types::PutProjectEventsResponse
Sends performance events to Evidently. These events can be used to evaluate a launch or an experiment.
2336 2337 2338 2339 |
# File 'lib/aws-sdk-cloudwatchevidently/client.rb', line 2336 def put_project_events(params = {}, = {}) req = build_request(:put_project_events, params) req.send_request() end |
#start_experiment(params = {}) ⇒ Types::StartExperimentResponse
Starts an existing experiment. To create an experiment, use [CreateExperiment].
[1]: docs.aws.amazon.com/cloudwatchevidently/latest/APIReference/API_CreateExperiment.html
2378 2379 2380 2381 |
# File 'lib/aws-sdk-cloudwatchevidently/client.rb', line 2378 def start_experiment(params = {}, = {}) req = build_request(:start_experiment, params) req.send_request() end |
#start_launch(params = {}) ⇒ Types::StartLaunchResponse
Starts an existing launch. To create a launch, use [CreateLaunch].
[1]: docs.aws.amazon.com/cloudwatchevidently/latest/APIReference/API_CreateLaunch.html
2447 2448 2449 2450 |
# File 'lib/aws-sdk-cloudwatchevidently/client.rb', line 2447 def start_launch(params = {}, = {}) req = build_request(:start_launch, params) req.send_request() end |
#stop_experiment(params = {}) ⇒ Types::StopExperimentResponse
Stops an experiment that is currently running. If you stop an experiment, you can’t resume it or restart it.
2489 2490 2491 2492 |
# File 'lib/aws-sdk-cloudwatchevidently/client.rb', line 2489 def stop_experiment(params = {}, = {}) req = build_request(:stop_experiment, params) req.send_request() end |
#stop_launch(params = {}) ⇒ Types::StopLaunchResponse
Stops a launch that is currently running. After you stop a launch, you will not be able to resume it or restart it. Also, it will not be evaluated as a rule for traffic allocation, and the traffic that was allocated to the launch will instead be available to the feature’s experiment, if there is one. Otherwise, all traffic will be served the default variation after the launch is stopped.
2536 2537 2538 2539 |
# File 'lib/aws-sdk-cloudwatchevidently/client.rb', line 2536 def stop_launch(params = {}, = {}) req = build_request(:stop_launch, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Assigns one or more tags (key-value pairs) to the specified CloudWatch Evidently resource. Projects, features, launches, and experiments can be tagged.
Tags can help you organize and categorize your resources. You can also use them to scope user permissions by granting a user permission to access or change only resources with certain tag values.
Tags don’t have any semantic meaning to Amazon Web Services and are interpreted strictly as strings of characters.
You can use the ‘TagResource` action with a resource that already has tags. If you specify a new tag key for the resource, this tag is appended to the list of tags associated with the alarm. If you specify a tag key that is already associated with the resource, the new tag value that you specify replaces the previous value for that tag.
You can associate as many as 50 tags with a resource.
For more information, see [Tagging Amazon Web Services resources].
2588 2589 2590 2591 |
# File 'lib/aws-sdk-cloudwatchevidently/client.rb', line 2588 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#test_segment_pattern(params = {}) ⇒ Types::TestSegmentPatternResponse
Use this operation to test a rules pattern that you plan to use to create an audience segment. For more information about segments, see [CreateSegment].
[1]: docs.aws.amazon.com/cloudwatchevidently/latest/APIReference/API_CreateSegment.html
2635 2636 2637 2638 |
# File 'lib/aws-sdk-cloudwatchevidently/client.rb', line 2635 def test_segment_pattern(params = {}, = {}) req = build_request(:test_segment_pattern, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Removes one or more tags from the specified resource.
2662 2663 2664 2665 |
# File 'lib/aws-sdk-cloudwatchevidently/client.rb', line 2662 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#update_experiment(params = {}) ⇒ Types::UpdateExperimentResponse
Updates an Evidently experiment.
Don’t use this operation to update an experiment’s tag. Instead, use [TagResource].
[1]: docs.aws.amazon.com/cloudwatchevidently/latest/APIReference/API_TagResource.html
2808 2809 2810 2811 |
# File 'lib/aws-sdk-cloudwatchevidently/client.rb', line 2808 def update_experiment(params = {}, = {}) req = build_request(:update_experiment, params) req.send_request() end |
#update_feature(params = {}) ⇒ Types::UpdateFeatureResponse
Updates an existing feature.
You can’t use this operation to update the tags of an existing feature. Instead, use [TagResource].
[1]: docs.aws.amazon.com/cloudwatchevidently/latest/APIReference/API_TagResource.html
2926 2927 2928 2929 |
# File 'lib/aws-sdk-cloudwatchevidently/client.rb', line 2926 def update_feature(params = {}, = {}) req = build_request(:update_feature, params) req.send_request() end |
#update_launch(params = {}) ⇒ Types::UpdateLaunchResponse
Updates a launch of a given feature.
Don’t use this operation to update the tags of an existing launch. Instead, use [TagResource].
[1]: docs.aws.amazon.com/cloudwatchevidently/latest/APIReference/API_TagResource.html
3061 3062 3063 3064 |
# File 'lib/aws-sdk-cloudwatchevidently/client.rb', line 3061 def update_launch(params = {}, = {}) req = build_request(:update_launch, params) req.send_request() end |
#update_project(params = {}) ⇒ Types::UpdateProjectResponse
Updates the description of an existing project.
To create a new project, use [CreateProject].
Don’t use this operation to update the data storage options of a project. Instead, use [UpdateProjectDataDelivery].
Don’t use this operation to update the tags of a project. Instead, use [TagResource].
[1]: docs.aws.amazon.com/cloudwatchevidently/latest/APIReference/API_CreateProject.html [2]: docs.aws.amazon.com/cloudwatchevidently/latest/APIReference/API_UpdateProjectDataDelivery.html [3]: docs.aws.amazon.com/cloudwatchevidently/latest/APIReference/API_TagResource.html
3143 3144 3145 3146 |
# File 'lib/aws-sdk-cloudwatchevidently/client.rb', line 3143 def update_project(params = {}, = {}) req = build_request(:update_project, params) req.send_request() end |
#update_project_data_delivery(params = {}) ⇒ Types::UpdateProjectDataDeliveryResponse
Updates the data storage options for this project. If you store evaluation events, you an keep them and analyze them on your own. If you choose not to store evaluation events, Evidently deletes them after using them to produce metrics and other experiment results that you can view.
You can’t specify both ‘cloudWatchLogs` and `s3Destination` in the same operation.
3212 3213 3214 3215 |
# File 'lib/aws-sdk-cloudwatchevidently/client.rb', line 3212 def update_project_data_delivery(params = {}, = {}) req = build_request(:update_project_data_delivery, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3241 3242 3243 |
# File 'lib/aws-sdk-cloudwatchevidently/client.rb', line 3241 def waiter_names [] end |